"""This is the 'sanitiz.py' module provides the function sanitize, which goes through a list,
such as a list of times, and replaces the colons and hyphens with periods"""

def sanitize(time_string):
    if '-' in time_string:
        splitter='-'
    elif ':' in time_string:
        splitter=':'
    else:
        return(time_string)
    (min,sec)=time_string.split(splitter)
    return(min + '.' + sec)



from distutils.core import setup

setup(
    name            ='sanitiz',
    version         ='1.0.0',
    py_modules      =['sanitiz'],
    author          ='hpython',
    author_email    ='hfpython@headfirstlabs.com',
    url             ='http://www.headfirstlabs.com',
    description     ='Developed by Head First python that replaces colons and hyphens with periods within lists',
    )
